﻿using System.Windows;
using DoodleGrouper.View;
using DoodleGrouper.ViewModel;
using Seesmic.Sdp.Extensibility;

namespace DoodleGrouper
{
    /// <summary>
    /// Creates a new Timeline Item Action that allows you to add the item creator to a group.
    /// </summary>
    public class AddToGroup : ITimelineItemAction
    {
        private string _text;

        /// <summary>
        /// Determines whether this instance can execute the specified timeline item container.
        /// </summary>
        /// <param name="timelineItemContainer">The timeline item container.</param>
        /// <returns>
        /// 	<c>true</c> if this instance can execute the specified timeline item container; otherwise, <c>false</c>.
        /// </returns>
        /// <remarks>I assume that I could do some sort of funky logic here if I needed to.</remarks>
        public bool CanExecute(TimelineItemContainer timelineItemContainer)
        {
            return true;
        }

        /// <summary>
        /// Opens the <see cref="PickUserList"/> dialog so the user can select a group to add the user to..
        /// </summary>
        /// <param name="timelineItemContainer">The timeline item container.</param>
        public void Execute(TimelineItemContainer timelineItemContainer)
        {
            string username = timelineItemContainer.TimelineItem.Username;

            var model = new ViewModelAddToGroup {Username = username, UserLists = Plugin.UserLists};

            var pickUserList = new PickUserList(model);
            pickUserList.Show();
        }

        public DataTemplate Icon
        {
            get { return Plugin.Resources["UserListGroupPath"] as DataTemplate; }
        }

        public string Text
        {
            get { return "Add to group..."; }
            set { _text = value; }
        }
    }
}