﻿using System.Linq;
using System.Windows;
using DoodleGrouper.Classes;
using DoodleGrouper.View;
using DoodleGrouper.ViewModel;
using Seesmic.Sdp.Extensibility;

namespace DoodleGrouper
{
    /// <summary>
    /// Provides an action on each group column to modify the group.
    /// </summary>
    public class ModifyGroup : IColumnAction
    {
        private string _text;
        /// <summary>
        /// Gets or sets the name of the group.
        /// </summary>
        /// <value>The name of the group.</value>
        public string GroupName { get; set; }
        /// <summary>
        /// Gets or sets the container.
        /// </summary>
        /// <value>The container.</value>
        public IColumnView Container { get; set; }
        private IColumnViewable previousView;

        /// <summary>
        /// Gets or sets the text for the action.
        /// </summary>
        /// <value>The text.</value>
        public string Text
        {
            get { return "Modify this group..."; }
            set { _text = value; }
        }

        public DataTemplate Icon
        {
            get { return Plugin.Resources["RemoveFromGroupIconPath"] as DataTemplate; }
        }

        public bool CanExecute(IColumnView columnView)
        {
            return true;
        }

        public void Execute(IColumnView columnView)
        {
            SortableObservableCollection<string> usernames =
                Plugin.UserLists.Where(u => u.Name == GroupName).Single().Users;

            usernames.Sort(u => u);

            var model = new ViewModelModifyGroup(GroupName) {Usernames = usernames};

            // TODO: Modify this to swap out the column in place of the ModifyGroupWindow control.

            var pickUserList = new TempModifyGroupWindow(model);
            pickUserList.Show();

/*
            if (columnView == null)
            {
                columnView = Container;
            }

            var modifyColumnView = new ModifyGroupColumnView {Header = "Modify group: " + GroupName, Content = model};

            previousView = columnView.CurrentView;

            columnView.SetCurrentView(modifyColumnView);
*/
        }
    }
}