﻿using System.Windows;
using DoodleGrouper.Classes;
using Seesmic.Sdp.Extensibility;
using Seesmic.Sdp.Utils;

namespace DoodleGrouper
{
    /// <summary>
    /// A Sidebar Action that allows you to group users into lists that auto refresh.
    /// </summary>
    public class UserList : ISidebarAction
    {
        private readonly Timeline _GroupTimeline = new Timeline();
        private readonly SortableObservableCollection<string> _Users = new SortableObservableCollection<string>();
        private bool _isHighlighted;

        /// <summary>
        /// Gets or sets the name of the group.
        /// </summary>
        /// <value>The name.</value>
        public string Name { get; set; }

        /// <summary>
        /// Gets the group timeline.
        /// </summary>
        /// <value>The group timeline.</value>
        public Timeline GroupTimeline
        {
            get { return _GroupTimeline; }
        }

        /// <summary>
        /// Gets the list of users in this group.
        /// </summary>
        /// <value>The users.</value>
        public SortableObservableCollection<string> Users
        {
            get { return _Users; }
        }

        public virtual void Invoke(SidebarActionContext context)
        {
            _isHighlighted = true;
            OpenTimelineColumn(context);
        }

        public string PersistId
        {
            get { return Name; }
        }

        public DataTemplate Icon
        {
            get { return Plugin.Resources["UserListGroupPath"] as DataTemplate; }
        }

        public string Text
        {
            get { return Name; }
        }

        public bool IsHighlighted
        {
            get { return _isHighlighted; }
        }

        internal void OpenTimelineColumn(SidebarActionContext context)
        {
            var column = context.Space.AddTimelineColumn(this, _GroupTimeline, Name, Icon);

            column.AddHeaderAction(new ModifyGroup{GroupName = Name, Container = column});
        }
    }
}