﻿using System.Linq;
using System.Windows;
using System.Windows.Controls;
using DoodleGrouper.ViewModel;

namespace DoodleGrouper.View
{
    public partial class PickUserList : ChildWindow
    {
        private readonly string _Username;

        public PickUserList(ViewModelAddToGroup model)
        {
            _Username = model.Username;
            DataContext = model;
            InitializeComponent();
        }

        private void AddNewList_Click(object sender, RoutedEventArgs e)
        {
            Plugin.LogInfo(string.Format("PickUserList: Adding new user list: {0}", NewUserList.Text));
            if (!Plugin.UserLists.Any(u => u.Name == NewUserList.Text))
            {
                Plugin.LogInfo("PickUserList: User list not found, adding.");

                // Ideally we want to add the new list straight into the correct slot
                // Calling Sort directly on the collection will result in a lot of 
                // additional calls to CollectionChanged.
                var userList = Plugin.UserLists.OrderBy(u => u.Name).Select(u => u.Name).ToList();
                userList.Add(NewUserList.Text);
                userList.Sort();

                Plugin.UserLists.Insert(userList.IndexOf(NewUserList.Text), new UserList {Name = NewUserList.Text});
            }
        }

        private void OKButton_Click(object sender, RoutedEventArgs e)
        {
            Plugin.LogInfo("PickUserList: Ok button clicked.");

            if (null != ExistingUserLists.SelectedItem)
            {
                string userListName = ((UserList) ExistingUserLists.SelectedItem).Name;
                Plugin.LogInfo(string.Format("PickUserList: Adding user to list: {0}",
                                             userListName));

                UserList userList = Plugin.UserLists.Where(u => u.Name == userListName).Single();

                if (!userList.Users.Contains(_Username))
                {
                    Plugin.LogInfo("PickUserList: User not in list, adding.");
                    userList.Users.Add(_Username);
                    userList.Users.Sort(u => u);
                    Plugin.SaveUserLists();
                }
            }

            DialogResult = true;
        }

        private void CancelButton_Click(object sender, RoutedEventArgs e)
        {
            DialogResult = false;
        }
    }
}