﻿using System.Linq;
using System.Windows;
using System.Windows.Controls;
using DoodleGrouper.ViewModel;

namespace DoodleGrouper.View
{
    /// <summary>
    /// Placeholder window for modifying the details of a group.
    /// </summary>
    /// <remarks>
    /// I'd like to get my head around swapping in a new page for the existing columns, 
    /// without having to create a whole new column just to handle this.
    /// </remarks>
    public partial class TempModifyGroupWindow : ChildWindow
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="TempModifyGroupWindow"/> class, along with details of the group in the model.
        /// </summary>
        /// <param name="model">The model.</param>
        public TempModifyGroupWindow(ViewModelModifyGroup model)
        {
            DataContext = model;
            InitializeComponent();
        }

        private void OKButton_Click(object sender, RoutedEventArgs e)
        {
            UserList group = getUserList();

            if (group != null)
            {
                string newGroupName = GroupName.Text;

                if (newGroupName != null)
                {
                    if (group.Name != newGroupName)
                    {
                        group.Name = newGroupName;
                    }
                }

                foreach (object user in ExistingUsers.SelectedItems)
                {
                    group.Users.Remove((string) user);
                }
            }

            Plugin.SaveUserLists();

            DialogResult = true;
        }

        private void CancelButton_Click(object sender, RoutedEventArgs e)
        {
            DialogResult = false;
        }

        private void AddButton_Click(object sender, RoutedEventArgs e)
        {
            UserList group = getUserList();

            if (!group.Users.Contains(AddUser.Text))
            {
                group.Users.Add(AddUser.Text);
                group.Users.Sort(u => u);
            }

            AddUser.Text = string.Empty;
        }

        private UserList getUserList()
        {
            var model = DataContext as ViewModelModifyGroup;

            UserList group = null;

            if (model != null)
            {
                group = Plugin.UserLists.Where(u => u.Name == model.GroupName).Single();
            }

            return group;
        }
    }
}